import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  arc,
  pie,
  scaleBand,
  scaleLinear,
  max,
} from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/kazokuma/f9fc1812bd7c2297c2a7699ecb4f78ea/raw/e648623b15830af659a1333eebcc78ade01820d7/UN_Population_2019.csv';
const width = 960;
const height = 500;
const margin = {
  top: 20,
  right: 20,
  bottom: 20,
  left: 200,
};
const innerHeight = height - margin.top - margin.bottom;
const innerWidth = width - margin.left - margin.right;

const App = () => {
  const [data, setData] = useState(null);
  useEffect(() => {
    const row = (d) => {
      d.Population = parseFloat(d['2020']);
      return d;
    };

    csv(csvUrl, row).then((data) => {
      setData(data.slice(0, 10));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const yScale = scaleBand()
    .domain(data.map((d) => d.Country))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, (d) => d.Population)])
    .range([0, innerWidth]);
  
  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        {xScale.ticks().map((tickValue) => (
          <g
            key={tickValue}
            transform={`translate(${xScale(tickValue)}, 0)`}
          >
            <line y2={innerHeight} stroke="black" /> //
            x1=0, y1=0, x2=0 can be eliminated because they
            are defalu values.
            <text
              style={{ textAnchor: 'middle' }}
              y={innerHeight + 3}
              dy="0.72em"
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map((tickValue) => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy="0.32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map((d) => (
          <rect
            key={d.Country}
            x={0}
            y={yScale(d.Country)}
            width={xScale(d.Population)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
  return;
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
